@@ -33,19 +33,22 @@
 #endif
 
 #include "xlplayer.h"
+#include "mp3tagread.h"
 
 struct avcodecdecode_vars
-   {
-   AVCodec *codec;
-   AVPacket pkt;
-   AVCodecContext *c;
-   AVFormatContext *ic;
-   int resample;
-   unsigned int stream;
-   uint8_t *outbuf;
-   float *floatsamples;
-   float drop;
-   };
+    {
+    AVCodec *codec;
+    AVPacket pkt;
+    AVCodecContext *c;
+    AVFormatContext *ic;
+    int resample;
+    unsigned int stream;
+    AVFrame *frame;
+    float *floatsamples;
+    float drop;
+    struct mp3taginfo taginfo;
+    struct chapter *current_chapter;
+    };
 
 int avcodecdecode_reg(struct xlplayer *xlplayer);
 void avformatinfo(char *pathname);
